bayespy.inference.vmp.nodes.beta.BetaDistribution.compute_fixed_moments_and_f
=============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.beta

.. automethod:: BetaDistribution.compute_fixed_moments_and_f